@@ -3,6 +3,8 @@
 from re import compile  # pylint: disable=W0622
 from typing import NamedTuple, Union
 
+from mcipc.rcon.exceptions import NotALocation
+
 
 __all__ = ['Location']
 
@@ -25,15 +27,19 @@ class Location(NamedTuple):
     """A 3D location."""
 
     x: int
-    y: int
+    y: Union[int, None]
     z: int
 
     @classmethod
     def from_response(cls, text: str):
         """Creates a location from a server response."""
         match = REGEX.fullmatch(text)
-        coordinates = (_int_or_none(item) for item in match.groups())
-        return cls(*coordinates)
+
+        if match is None:
+            raise NotALocation(text)
+
+        coord_x, coord_y, coord_z = match.groups()
+        return cls(int(coord_x), _int_or_none(coord_y), int(coord_z))
 
     def to_json(self) -> dict:
         """Returns a JSON-ish dict."""
