@@ -1,13 +1,27 @@
 """RCON exceptions."""
 
 
-__all__ = ['InvalidPacketStructure', 'RequestIdMismatch', 'WrongPassword']
+__all__ = [
+    'InvalidPacketStructure',
+    'InvalidStructure',
+    'NotALocation',
+    'RequestIdMismatch',
+    'WrongPassword'
+]
 
 
-class InvalidPacketStructure(Exception):
+class InvalidPacketStructure(ValueError):
     """Indicates an invalid packet structure."""
 
 
+class InvalidStructure(ValueError):
+    """Indicates that the given Minecraft structure is not valid."""
+
+
+class NotALocation(ValueError):
+    """Indicates that the given text is not a valid location value."""
+
+
 class RequestIdMismatch(Exception):
     """Indicates that the sent and received request IDs do not match."""
 
